@@ -29,6 +29,7 @@
 #include "connectiondialog.h"
 #include "optionsdialog.h"
 #include "libraryviewdialog.h"
+#include "woldialog.h"
 #include "squeezeresponse.h"
 #include "xmltreeitem.h"
 #include "xmllistitem.h"
@@ -46,7 +47,7 @@
 #define INSTALLMSGHANDLER
 //#define NODEBUG
 //#define DEBUGTOFILE
-//#define DEBUGTOSTDERR
+#define DEBUGTOSTDERR
 
 // Constants;
 #define NORMALSCREENOFFSET 46
@@ -66,6 +67,7 @@
 #define STATUSTAGS "tags:alsdxK"
 #define ALBUMTAGS "tags:ailjce"
 #define IDTAGS "tags:pse"
+#define DUMMYPLAYERNAME "SqueezsterDummyPlayer123"
 
 QTM_USE_NAMESPACE
 
@@ -277,12 +279,14 @@ private:
 private slots:
     void startApp(bool isOnline=true);
     void constructConnDialog();
+//    void constructWOLDialog();
     void screensaverInhibitSlot(bool ssInhibit);
     void largeAlbumIconsSlot(bool largeAlbumIcons);
     bool requestConnect();
     void requestConnect(const UserSettings &newSettings);
     void httpAuthentSlot(QNetworkReply* networkReply, QAuthenticator* authenticator);
     void initEnvironment();
+    void reInitEnvironment();
     void initUI();
     void updateNowPlayingIcons();
     void slotOptions();
@@ -318,7 +322,7 @@ private slots:
     void updateProgress();
 
     void updateActivePlayer(int index);
-    void requestCurrentPlaylist();
+ //   void requestCurrentPlaylist();
     void requestSqueezeList(const QString command, quint16 count=100, quint16 start=0, quint16 batch=0, QString tags=QString());
     void requestSqueezeList(const QStringList command, quint16 count=100, quint16 start=0, quint16 batch=0, QString tags=QString());
     void playlistItemClicked(QListWidgetItem* song);
@@ -360,6 +364,8 @@ private slots:
     QString getKeyValue(QString responseString, QString keyName, bool* ok=0);
     QString getInitValue(QString responseString, QString keyName);
     QString getFirstKey(QStringList parameters, QString keyName);
+    QString findKeyValue(QStringList* stringListPtr, QString* keyNamePtr, bool* ok=0);
+
 
     void receiveUdpDatagram();
     void serverDiscovery();
