@@ -9,6 +9,7 @@
 #define IPADDRESS "127.0.0.1"
 #define HTTPPORT 9000
 #define CLIPORT 9090
+#define WOLPORT 3483
 #define CONFIGFILE ".squeezster.config"
 
 class UserSettings
@@ -30,6 +31,8 @@ public:
     bool    setScreensaverIsInhibited(bool newScreensaverIsInhibited);
     bool    setLargeAlbumIcons(bool newLargeAlbumIcons);
     bool    setAlbumIcons(bool newAlbumIcons);
+    QString setWolMac(QString newWolMac);
+    quint16 setWolPort(quint16 newWolPort);
 
     QString username() const {return(username_i);}
     QString password() const {return(password_i);}
@@ -39,6 +42,8 @@ public:
     bool    screensaverIsInhibited() const {return(screensaverIsInhibited_i);}
     bool    largeAlbumIcons() const {return(largeAlbumIcons_i);}
     bool    albumIcons() const {return(albumIcons_i);}
+    QString wolMac() const {return(wolMac_i);}
+    quint16 wolPort() const {return(wolPort_i);}
 
     //bool load();
     //bool save();
@@ -60,6 +65,8 @@ private:
     bool    screensaverIsInhibited_i;
     bool    largeAlbumIcons_i;
     bool    albumIcons_i;
+    QString wolMac_i;
+    quint16 wolPort_i;
 };
 
 #endif // USERSETTINGS_H
