@@ -32,10 +32,8 @@ public:
     void setIcon(QIcon icon) {QTreeWidgetItem::setIcon(0,icon);}
     QString command() {return(property("cmd"));}
     QString id() {return(property("id"));}
-    QString item_id() {
-        if (!property("id").isEmpty())
-            return(QString("item_id:"+property("id")));
-        else return(QString());}
+    QString item_id() {return(QString("item_id:"+property("id")));
+    }
     QString album_id() {
         if(!property("album").isEmpty())
             return(QString("album_id:"+property("id")));
